==> cryostat-rhel8-operator-container-2.0.0-5.tar.gz: cryostat-rhel8-operator-container-2.0.0-5/app/internal/tools/imagetag_generator.go <==
// Copyright The Cryostat Authors
//
// The Universal Permissive License (UPL), Version 1.0
//
// Subject to the condition set forth below, permission is hereby granted to any
// person obtaining a copy of this software, associated documentation and/or data
// (collectively the "Software"), free of charge and under any and all copyright
// rights in the Software, and any and all patent rights owned or freely
// licensable by each licensor hereunder covering either (i) the unmodified
// Software as contributed to or provided by such licensor, or (ii) the Larger
// Works (as defined below), to deal in both
//
// (a) the Software, and
// (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
// one is included with the Software (each a "Larger Work" to which the Software
// is contributed by such licensors),
//
// without restriction, including without limitation the rights to copy, create
// derivative works of, display, perform, and distribute the Software and make,
// use, sell, offer for sale, import, export, have made, and have sold the
// Software and the Larger Work(s), and to sublicense the foregoing rights on
// either these or other terms.
//
// This license is subject to the following condition:
// The above copyright notice and either this complete permission notice or at
// a minimum a reference to the UPL must be included in all copies or
// substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

// +build ignore

package main

import (
	"log"
	"os"
	"text/template"
)

const coreImageEnv = "CORE_IMG"
const datasourceImageEnv = "DATASOURCE_IMG"
const grafanaImageEnv = "GRAFANA_IMG"

// This program generates a imagetag_generated.go file containing image tag
// constants for each container image deployed by the operator. These constants
// are populated using environment variables.
func main() {
	// Fill in image tags struct from the environment variables
	imageTags := struct {
		CoreImageTag       string
		DatasourceImageTag string
		GrafanaImageTag    string
	}{
		CoreImageTag:       getEnvVar(coreImageEnv),
		DatasourceImageTag: getEnvVar(datasourceImageEnv),
		GrafanaImageTag:    getEnvVar(grafanaImageEnv),
	}

	// Create the source file to generate
	file, err := os.Create("imagetag_generated.go")
	if err != nil {
		log.Fatal(err)
	}
	defer file.Close()

	err = fileTemplate.Execute(file, imageTags)
	if err != nil {
		log.Fatal(err)
	}
}

func getEnvVar(name string) string {
	val, pres := os.LookupEnv(name)
	if !pres {
		log.Fatalf("Environment variable for image tag %s not defined", name)
	}
	return val
}

var fileTemplate = template.Must(template.New("").Parse(`// Code generated by imagetag_generator.go; DO NOT EDIT.
package resource_definitions

// Default image tag for the core application image
const DefaultCoreImageTag = "{{ .CoreImageTag }}"

// Default image tag for the JFR datasource image
const DefaultDatasourceImageTag = "{{ .DatasourceImageTag }}"

// Default image tag for the Grafana dashboard image
const DefaultGrafanaImageTag = "{{ .GrafanaImageTag }}"
`))

==> cryostat-rhel8-operator-container-2.1.0-1.tar.gz: cryostat-rhel8-operator-container-2.1.0-1/app/internal/tools/imagetag_generator.go <==
// Copyright The Cryostat Authors
//
// The Universal Permissive License (UPL), Version 1.0
//
// Subject to the condition set forth below, permission is hereby granted to any
// person obtaining a copy of this software, associated documentation and/or data
// (collectively the "Software"), free of charge and under any and all copyright
// rights in the Software, and any and all patent rights owned or freely
// licensable by each licensor hereunder covering either (i) the unmodified
// Software as contributed to or provided by such licensor, or (ii) the Larger
// Works (as defined below), to deal in both
//
// (a) the Software, and
// (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
// one is included with the Software (each a "Larger Work" to which the Software
// is contributed by such licensors),
//
// without restriction, including without limitation the rights to copy, create
// derivative works of, display, perform, and distribute the Software and make,
// use, sell, offer for sale, import, export, have made, and have sold the
// Software and the Larger Work(s), and to sublicense the foregoing rights on
// either these or other terms.
//
// This license is subject to the following condition:
// The above copyright notice and either this complete permission notice or at
// a minimum a reference to the UPL must be included in all copies or
// substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

// +build ignore

package main

import (
	"log"
	"os"
	"text/template"
)

const coreImageEnv = "CORE_IMG"
const datasourceImageEnv = "DATASOURCE_IMG"
const grafanaImageEnv = "GRAFANA_IMG"
const reportsImageEnv = "REPORTS_IMG"

// This program generates a imagetag_generated.go file containing image tag
// constants for each container image deployed by the operator. These constants
// are populated using environment variables.
func main() {
	// Fill in image tags struct from the environment variables
	imageTags := struct {
		CoreImageTag       string
		DatasourceImageTag string
		GrafanaImageTag    string
		ReportsImageTag    string
	}{
		CoreImageTag:       getEnvVar(coreImageEnv),
		DatasourceImageTag: getEnvVar(datasourceImageEnv),
		GrafanaImageTag:    getEnvVar(grafanaImageEnv),
		ReportsImageTag:    getEnvVar(reportsImageEnv),
	}

	// Create the source file to generate
	file, err := os.Create("imagetag_generated.go")
	if err != nil {
		log.Fatal(err)
	}
	defer file.Close()

	err = fileTemplate.Execute(file, imageTags)
	if err != nil {
		log.Fatal(err)
	}
}

func getEnvVar(name string) string {
	val, pres := os.LookupEnv(name)
	if !pres {
		log.Fatalf("Environment variable for image tag %s not defined", name)
	}
	return val
}

var fileTemplate = template.Must(template.New("").Parse(`// Code generated by imagetag_generator.go; DO NOT EDIT.
package resource_definitions

// Default image tag for the core application image
const DefaultCoreImageTag = "{{ .CoreImageTag }}"

// Default image tag for the JFR datasource image
const DefaultDatasourceImageTag = "{{ .DatasourceImageTag }}"

// Default image tag for the Grafana dashboard image
const DefaultGrafanaImageTag = "{{ .GrafanaImageTag }}"

// Default image tag for the Grafana dashboard image
const DefaultReportsImageTag = "{{ .ReportsImageTag }}"
`))
